summary refs log tree commit diff
path: root/tests/unittest.py
diff options
context:
space:
mode:
authorreivilibre <oliverw@matrix.org>2022-02-02 09:59:55 +0000
committerGitHub <noreply@github.com>2022-02-02 09:59:55 +0000
commit513913cc6ba77833082178b7d2b2f0565daf3c99 (patch)
tree91793eeab833e6ebb96bd55fba9e271db24a4266 /tests/unittest.py
parentConvert `ApplicationServiceTestCase` to use `simple_async_mock` (#11880) (diff)
downloadsynapse-513913cc6ba77833082178b7d2b2f0565daf3c99.tar.xz
Expose the registered device ID from the `register_appservice_user` test helper. (#11615)
Diffstat (limited to 'tests/unittest.py')
-rw-r--r--tests/unittest.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/tests/unittest.py b/tests/unittest.py
index 1431848367..6fc617601a 100644
--- a/tests/unittest.py
+++ b/tests/unittest.py
@@ -620,18 +620,19 @@ class HomeserverTestCase(TestCase):
         self,
         username: str,
         appservice_token: str,
-    ) -> str:
+    ) -> Tuple[str, str]:
         """Register an appservice user as an application service.
         Requires the client-facing registration API be registered.
 
         Args:
             username: the user to be registered by an application service.
-                Should be a full username, i.e. ""@localpart:hostname" as opposed to just "localpart"
+                Should NOT be a full username, i.e. just "localpart" as opposed to "@localpart:hostname"
             appservice_token: the acccess token for that application service.
 
         Raises: if the request to '/register' does not return 200 OK.
 
-        Returns: the MXID of the new user.
+        Returns:
+            The MXID of the new user, the device ID of the new user's first device.
         """
         channel = self.make_request(
             "POST",
@@ -643,7 +644,7 @@ class HomeserverTestCase(TestCase):
             access_token=appservice_token,
         )
         self.assertEqual(channel.code, 200, channel.json_body)
-        return channel.json_body["user_id"]
+        return channel.json_body["user_id"], channel.json_body["device_id"]
 
     def login(
         self,